@@ -2584,19 +2584,23 @@ process_input (buffer * buf)
                 break;
 
             case LPE_NEXTBUF_KEY:
-                key_nextbuf();
+               if(is_help) key_help(buf);
+               else key_nextbuf();
                 break;
 
             case LPE_PREVBUF_KEY:
-                key_prevbuf();
+               if(is_help) key_help(buf);
+                else key_prevbuf();
                 break;
 
             case LPE_OPENBUF_KEY:
+               if(is_help) key_help(buf);
                 key_openbuf();
                 break;
 
             case LPE_CLOSEBUF_KEY:
-                key_closebuf();
+                if(is_help) key_help(buf);
+                else key_closebuf();
 		break;
 
 	    case LPE_DEBUG_KEY:
